﻿$ErrorActionPreference = 'Stop'; # stop on all errors

# QGIS install is best done with older versions uninstalled
[array]$key = Get-UninstallRegistryKey -SoftwareName "QGIS *"

if ($key.Count -eq 1) {
   $oldVersion = $key[0].PSChildName -replace ".* ([0-9.]*)",'$1'
   $RemoveProc = Start-Process -FilePath $key[0].UninstallString -ArgumentList '/S' -PassThru
   $updateId = $RemoveProc.Id
   Write-Host "Uninstalling old version of QGIS." -ForegroundColor Cyan
   Write-Debug "Uninstall Process ID:`t$updateId"
   $RemoveProc.WaitForExit()
} elseif ($key.Count -gt 1) {
   Throw "Multiple, previous installs found!  Cannot proceed with install of new version."
}

# The QGIS uninstaller sometimes leaves stuff behind that still prevents install (grr!)
$OldKey = Get-ChildItem HKLM:\SOFTWARE | 
            Where-Object {$_.name -match "QGIS ([0-9.]*)"} |
            Select-Object -ExpandProperty Name
if ($OldKey) {
   $oldVersion = $OldKey -replace ".*QGIS ([0-9.]*)",'$1'
   Remove-Item -Path "HKLM:\Software\QGIS $oldVersion" -Recurse
}
# AND it leaves behind dead public desktop shortcuts
$OldLinks = ("QGIS $oldVersion",
            "OSGeo4W Shell.lnk",
            "GRASS GIS *.lnk")
Foreach ($item in $OldLinks) {
   if (Test-Path "$env:PUBLIC\Desktop\$item") { Remove-Item "$env:PUBLIC\Desktop\$item" -Recurse -Force }
}

$packageArgs = @{
   packageName    = $env:ChocolateyPackageName
   fileType       = 'EXE'
   softwareName   = "$env:ChocolateyPackageName $env:ChocolateyPackageVersion*"
   url            = 'http://qgis.org/downloads/QGIS-OSGeo4W-2.18.15-1-Setup-x86.exe'
   url64bit       = 'http://qgis.org/downloads/QGIS-OSGeo4W-2.18.15-1-Setup-x86_64.exe'
   checksumType   = 'sha256'
   checksum       = 'a9776c0b29bf7eeb84a22ba098470b565684e59972ea8feb35cbcab8da671cb3'
   checksum64     = 'f60555c69e21ead03acb63d35cf1ab5e546bad61676d88d8956c95e0c36d70bb'
   silentArgs     = '/S'
   validExitCodes = @(0)
}

Write-Host "Installing QGIS can take a few minutes.  Please be patient." -ForegroundColor Cyan
Install-ChocolateyPackage @packageArgs
